@@ -54,7 +54,8 @@ class HTTPClient(object):
             return self._request('get', path, params=params)
 
         results = list()
-        params['page'] = 1
+        current_page = 1
+        params['page'] = current_page
         params['page_size'] = page_size
         params['pagination'] = True
         first_result = self._request('get', path, params=params)
@@ -62,12 +63,15 @@ class HTTPClient(object):
         current_page = first_result.get('page', 1)
         results.extend(first_result['items'])
 
-        while current_page < num_pages:
+        while num_pages > current_page:
             params['page'] = current_page + 1
             next_result = self._request('get', path, params=params)
             current_page = next_result['page']
             num_pages = next_result['page_count']
-            results.extend(next_result.get('items', []))
+            items = next_result.get('items')
+            if not items:
+                break
+            results.extend(items)
 
         return results
 
